atomate.feff package
====================

Subpackages
-----------

.. toctree::

    atomate.feff.firetasks
    atomate.feff.fireworks
    atomate.feff.workflows

Submodules
----------

atomate.feff.database module
----------------------------

.. automodule:: atomate.feff.database
    :members:
    :undoc-members:
    :show-inheritance:

atomate.feff.utils module
-------------------------

.. automodule:: atomate.feff.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: atomate.feff
    :members:
    :undoc-members:
    :show-inheritance:
